@@ -2,7 +2,9 @@ package Test::BrewBuild::BrewCommands;
 use strict;
 use warnings;
 
-our $VERSION = '1.03_03';
+use version;
+
+our $VERSION = '1.05_01';
 
 my $log;
 
@@ -15,24 +17,53 @@ sub new {
     $log = $self->{log};
     $log->_6("constructing new Test::BrewBuild::BrewCommands object");
 
+    $self->brew;
+
     return $self;
 }
 sub brew {
     my $self = shift;
-    my $brew = $self->is_win ? 'berrybrew' : 'perlbrew';
+
+    return $self->{brew} if $self->{brew};
+
+    my $brew;
+
+    if ($self->is_win){
+        my $exe_loc = `where berrybrew.exe`;
+        $brew = (split /\n/, $exe_loc)[0];
+    }
+    else {
+        $brew = 'perlbrew';
+    }
+
     $log->child('brew')->_6("*brew cmd is: $brew");
+    $self->{brew} = $brew;
+
     return $brew;
 }
+sub info {
+    my $self = shift;
+    return $self->is_win
+        ? `$self->{brew} available 2>nul`
+        : `perlbrew available 2>/dev/null`;
+}
 sub installed {
-    my ($self, $info) = @_;
+    my ($self, $legacy, $info) = @_;
 
     $log->child('installed')->_6("cleaning up perls installed");
 
     return if ! $info;
 
-    return $self->is_win
+    my @installed = $self->is_win
         ? $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]/ig
         : $info =~ /i.*?(perl-\d\.\d+\.\d+)/g;
+
+    if (! $legacy){
+        @installed = grep { /^(?:perl-)?\d\.(\d+)/; $1 >= 8 } @installed;
+    }
+
+    return @installed;
+
 }
 sub using {
     my ($self, $info) = @_;
@@ -44,40 +75,31 @@ sub using {
         return $installed[0];
     }
     else {
-        my $using = $^V;
+        my $using = version->parse($])->normal;
         $using =~ s/v//;
         $using = "perl-$using";
         return $using;
     }
 }
 sub available {
-    my ($self, $info) = @_;
+    my ($self, $legacy, $info) = @_;
 
+    $log->child('available')->_6("determining available perls");
 
-    if ($info){
+    my @avail = $self->is_win
+        ? $info =~ /(\d\.\d+\.\d+_\d+)/g
+        : $info =~ /(perl-\d\.\d+\.\d+)/g;
 
-        $log->child('available')->_6("determining available perls");
-
-        my @avail = $self->is_win
-            ? $info =~ /(\d\.\d+\.\d+_\d+)/g
-            : $info =~ /(perl-\d\.\d+\.\d+)/g;
-
-        return @avail;
-    }
-    else {
-
-        $log->child('available')->_6("generating available");
-
-        return $self->is_win
-            ? `berrybrew available 2>nul`
-            : `perlbrew available 2>/dev/null`;
+    if (! $legacy){
+        @avail = grep { /^(?:perl-)?\d\.(\d+)/; $1 > 8 } @avail;
     }
+    return @avail;
 }
 sub install {
     my $self = shift;
 
     my $install_cmd = $self->is_win
-        ? 'berrybrew install'
+        ? "$self->{brew} install"
         : 'perlbrew install --notest -j 4';
 
     $log->child('install')->_6("install cmd is: $install_cmd");
@@ -88,7 +110,7 @@ sub remove {
     my $self = shift;
 
     my $remove_cmd = $self->is_win
-        ? 'berrybrew remove'
+        ? "$self->{brew} remove"
         : 'perlbrew uninstall';
 
     $log->child('remove')->_6("remove cmd is: $remove_cmd");
@@ -105,7 +127,7 @@ sub is_win {
 =head1 NAME
 
 Test::BrewBuild::BrewCommands - Provides Windows/Unix *brew command
-translations.
+translations for Test::BrewBuild
 
 =head1 METHODS
 
@@ -115,28 +137,35 @@ Returns a new Test::BrewBuild::BrewCommands object.
 
 =head2 brew
 
-Returns 'perlbrew' if on Unix, and 'berrybrew' if on Windows.
+Returns C<perlbrew> if on Unix, and the full executable path for
+C<berrybrew.exe> if on Windows.
+
+=head2 info
+
+Returns the string result of C<*brew available>.
 
 =head2 installed($info)
 
-Takes the output of '*brew available' in a string form. Returns the currently
+Takes the output of C<*brew available> in a string form. Returns the currently
 installed versions, formatted in a platform specific manner.
 
-=head2 available($info)
-
-Similar to C<installed()>, but returns all perls available.
-
 =head2 using($info)
 
-Returns the current version of perl we're using.
+Returns the current version of perl we're using. $info is the output from
+C<info()>.
+
+=head2 available($legacy, $info)
+
+Similar to C<installed()>, but returns all perls available. If C<$legacy> is
+false, we'll only return C<perl> versions C<5.8.0+>.
 
 =head2 install
 
-Returns the current OS's specific *brew install command.
+Returns the current OS's specific C<*brew install> command.
 
 =head2 remove
 
-Returns the current OS's specific *brew remove command.
+Returns the current OS's specific C<*brew remove> command.
 
 =head2 is_win
 
@@ -169,4 +198,4 @@ See L<http://dev.perl.org/licenses/> for more information.
 
 
 =cut
-
+ 
